import Vue from 'vue'
import Router from 'vue-router'
// import menuNoShowData from './menu.js'
import { getStorageMenu } from '@/utils/auth'
Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export let moreRoutes = [
  {
    path: '/base',
    component: Layout,
    redirect: '/base/dict',
    name: 'Base',
    alwaysShow: true,
    meta: { title: '系统配置', icon: 'dashboard' },
    children: [
      {
        path: 'dict',
        name: 'Dict',
        component: () => import('@/views/base/dict'),
        meta: { title: '系统字典' }
      },
      {
        path: 'menu',
        name: 'Menu',
        component: () => import('@/views/base/menu'),
        meta: { title: '菜单配置' }
      },
      {
        path: 'role',
        name: 'role',
        component: () => import('@/views/base/role'),
        meta: { title: '角色权限' }
      },
      {
        path: 'dictDtl',
        name: 'DictDtl',
        hidden: true,
        component: () => import('@/views/base/dictDtl'),
        meta: { title: '系统字典详情' }
      }
    ]
  },
  {
    path: '/user',
    component: Layout,
    redirect: '/user/app',
    meta: { title: '用户管理', icon: 'dashboard' },
    children: [
      {
        path: 'app',
        name: 'UserApp',
        component: () => import('@/views/user/app'),
        meta: { title: '用户管理', affix: true }
      },
      {
        path: 'index',
        name: 'UserIndex',
        component: () => import('@/views/user/index'),
        meta: { title: '后台用户管理', affix: true }
      },
    ]
  },
]
function formatStr (str) {
  let newStr = ''
  str.slice(1).split('/').map((item, i) => {
    if (i > 0) {
      newStr += item.slice(0, 1).toUpperCase() + item.slice(1)
    } else {
      newStr += item
    }
  })
  return newStr
}


function formateMenu (arr) {
  let cArr = []
  arr.forEach(item => {
    if (item.perm_type === '1' || item.perm_type === '2') {
      let cObj = {
        path: item.path,
        name: formatStr(item.path),
        component: resolve => require([`@/views${item.path}`], resolve),
        meta: { title: item.name },
      }
      if (item.menu_hidden === '2') cObj.hidden = true
      if (item.children && item.children.length > 0) {
        cObj.children = formateMenu(item.children)
      } else {
        delete cObj.children
      }
      cArr.push(cObj)
    }
  })
  return cArr
}

let asyncRoutes = []
const getMenu = () => {
  const menuDataArr = getStorageMenu()
  menuDataArr.forEach(item => {
    let cObj = {
      path: item.path,
      component: Layout,
      meta: { title: item.name, icon: 'dashboard' },
    }
    if (item.children && item.children.length > 0) {
      cObj.children = formateMenu(item.children)
    } else {
      cObj.path = `/${item.path.split('/')[1]}`
      cObj.children = [
        {
          path: item.path,
          name: formatStr(item.path),
          component: resolve => require([`@/views${item.path}`], resolve),
          meta: { title: item.name },
          // , affix: true
        }
      ]
      cObj.redirect = cObj.children[0].path
    }
    asyncRoutes.push(cObj)
  })
}
getMenu()
export const constantRoutes = [
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },
  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  },
  {
    path: '/map/dtl',
    component: () => import('@/views/map/dtl'),
    hidden: true
  },
  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    children: [{
      path: 'dashboard',
      name: 'Dashboard',
      component: () => import('@/views/dashboard/index'),
      meta: { title: '首页', icon: 'dashboard', affix: true }
    }]
  },
  // ...moreRoutes,
  ...asyncRoutes,
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})
const router = createRouter()
// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
